from psend import functions

if __name__ == "__main__":
    functions.main()